=====
pysbe
=====


.. image:: https://img.shields.io/pypi/v/pysbe.svg
        :target: https://pypi.python.org/pypi/pysbe

.. image:: https://img.shields.io/travis/bkc/pysbe.svg
        :target: https://travis-ci.org/bkc/pysbe

.. image:: https://readthedocs.org/projects/pysbe/badge/?version=latest
        :target: https://pysbe.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/bkc/pysbe/shield.svg
     :target: https://pyup.io/repos/github/bkc/pysbe/
     :alt: Updates



Python implementation of Simple Binary Encoding V1.0


* Free software: Apache Software License 2.0
* Documentation: https://pysbe.readthedocs.io.

Work in Progress

A python implementation of `FIX SBE https://github.com/FIXTradingCommunity/fix-simple-binary-encoding`



Features
--------

* TODO

References
-----------

* https://mechanical-sympathy.blogspot.com/2014/05/simple-binary-encoding.html
* https://github.com/real-logic/simple-binary-encoding/wiki/FIX-SBE-XML-Primer
* http://fixprotocol.io/fix-simple-binary-encoding/ - FIX specification
* https://github.com/real-logic/simple-binary-encoding/blob/master/sbe-tool/src/main/resources/fpl/SimpleBinary1-0.xsd - XSD for XML SBE schema spec
* https://capnproto.org/news/2014-06-17-capnproto-flatbuffers-sbe.html (comparison of protocols)


Credits
-------

This package was created with Cookiecutter_ and the
`audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
